@@ -1,24 +1,24 @@
-use crate::ast;
-use crate::{Spanned, ToTokens};
+use crate::ast::prelude::*;
 
 /// A return statement `<expr>.await`.
 ///
 /// # Examples
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
 /// testing::roundtrip::<ast::Expr>("(42).await");
 /// testing::roundtrip::<ast::Expr>("self.await");
 /// testing::roundtrip::<ast::Expr>("test.await");
 /// ```
 #[derive(Debug, Clone, PartialEq, Eq, ToTokens, Spanned)]
+#[non_exhaustive]
 pub struct ExprAwait {
     /// Attributes associated with expression.
     #[rune(iter)]
     pub attributes: Vec<ast::Attribute>,
     /// The expression being awaited.
-    pub expr: ast::Expr,
+    pub expr: Box<ast::Expr>,
     /// The dot separating the expression.
     pub dot: T![.],
     /// The await token.
