@@ -1,16 +1,16 @@
-use crate::ast;
-use crate::{Parse, Spanned, ToTokens};
+use crate::ast::prelude::*;
 
 /// A `continue` statement: `continue [label]`.
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
 /// testing::roundtrip::<ast::ExprContinue>("continue");
 /// testing::roundtrip::<ast::ExprContinue>("continue 'foo");
 /// ```
 #[derive(Debug, Clone, PartialEq, Eq, Parse, ToTokens, Spanned)]
 #[rune(parse = "meta_only")]
+#[non_exhaustive]
 pub struct ExprContinue {
     /// The attributes of the `break` expression
     #[rune(iter, meta)]
