@@ -1,10 +1,9 @@
-use crate::ast;
-use crate::{Spanned, ToTokens};
+use crate::ast::prelude::*;
 
 /// A field access `<expr>.<field>`.
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
 /// testing::roundtrip::<ast::ExprFieldAccess>("foo.bar");
 /// testing::roundtrip::<ast::ExprFieldAccess>("foo.bar::<A, B>");
@@ -13,12 +12,13 @@ use crate::{Spanned, ToTokens};
 /// testing::roundtrip::<ast::ExprFieldAccess>("(foo.0).1");
 /// ```
 #[derive(Debug, Clone, PartialEq, Eq, ToTokens, Spanned)]
+#[non_exhaustive]
 pub struct ExprFieldAccess {
     /// Attributes associated with expression.
     #[rune(iter)]
     pub attributes: Vec<ast::Attribute>,
     /// The expr where the field is being accessed.
-    pub expr: ast::Expr,
+    pub expr: Box<ast::Expr>,
     /// The parsed dot separator.
     pub dot: T![.],
     /// The field being accessed.
@@ -29,6 +29,7 @@ expr_parse!(FieldAccess, ExprFieldAccess, "field access expression");
 
 /// The field being accessed.
 #[derive(Debug, Clone, PartialEq, Eq, ToTokens, Spanned)]
+#[non_exhaustive]
 pub enum ExprField {
     /// An identifier.
     Path(ast::Path),
