@@ -1,17 +1,17 @@
-use crate::ast;
-use crate::{Spanned, ToTokens};
+use crate::ast::prelude::*;
 
 /// A prioritized expression group `(<expr>)`.
 ///
 /// # Examples
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
 /// testing::roundtrip::<ast::ExprGroup>("(for i in x {})");
 /// testing::roundtrip::<ast::ExprGroup>("(1 + 2)");
 /// ```
 #[derive(Debug, Clone, PartialEq, Eq, ToTokens, Spanned)]
+#[non_exhaustive]
 pub struct ExprGroup {
     /// Attributes associated with expression.
     #[rune(iter)]
@@ -19,7 +19,7 @@ pub struct ExprGroup {
     /// The open parenthesis.
     pub open: ast::OpenParen,
     /// The grouped expression.
-    pub expr: ast::Expr,
+    pub expr: Box<ast::Expr>,
     /// The close parenthesis.
     pub close: ast::CloseParen,
 }
