@@ -1,10 +1,9 @@
-use crate::ast;
-use crate::{Parse, Spanned, ToTokens};
+use crate::ast::prelude::*;
 
 /// A return expression `return [expr]`.
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
 /// testing::roundtrip::<ast::ExprReturn>("return");
 /// testing::roundtrip::<ast::ExprReturn>("return 42");
@@ -12,6 +11,7 @@ use crate::{Parse, Spanned, ToTokens};
 /// ```
 #[derive(Debug, Clone, Parse, PartialEq, Eq, ToTokens, Spanned)]
 #[rune(parse = "meta_only")]
+#[non_exhaustive]
 pub struct ExprReturn {
     /// The attributes of the `return` statement.
     #[rune(iter, meta)]
@@ -20,7 +20,7 @@ pub struct ExprReturn {
     pub return_token: T![return],
     /// An optional expression to return.
     #[rune(iter)]
-    pub expr: Option<ast::Expr>,
+    pub expr: Option<Box<ast::Expr>>,
 }
 
 expr_parse!(Return, ExprReturn, "return expression");
