@@ -1,18 +1,20 @@
-use crate::ast;
-use crate::{Parse, ParseError, Parser, Spanned, ToTokens};
+use crate::ast::prelude::*;
 
 /// An expression to construct a literal tuple.
 ///
 /// # Examples
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
+/// testing::roundtrip::<ast::ExprTuple>("()");
+/// testing::roundtrip::<ast::ExprTuple>("(1,)");
 /// testing::roundtrip::<ast::ExprTuple>("(1, \"two\")");
 /// testing::roundtrip::<ast::ExprTuple>("(1, 2,)");
 /// testing::roundtrip::<ast::ExprTuple>("(1, 2, foo())");
 /// ```
 #[derive(Debug, Clone, PartialEq, Eq, Parse, ToTokens, Spanned)]
+#[non_exhaustive]
 pub struct ExprTuple {
     /// Attributes associated with tuple.
     #[rune(iter, meta)]
@@ -23,7 +25,7 @@ pub struct ExprTuple {
 
 impl ExprTuple {
     /// Start parsing literal tuple from the middle of an expression.
-    pub fn parse_from_first_expr(
+    pub(crate) fn parse_from_first_expr(
         parser: &mut Parser<'_>,
         attributes: Vec<ast::Attribute>,
         open: ast::OpenParen,
