@@ -1,18 +1,18 @@
-use crate::ast;
-use crate::{Parse, Spanned, ToTokens};
+use crate::ast::prelude::*;
 
 /// A literal vector.
 ///
 /// # Examples
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
 /// testing::roundtrip::<ast::ExprVec>("[1, \"two\"]");
 /// testing::roundtrip::<ast::ExprVec>("[1, 2,]");
 /// testing::roundtrip::<ast::ExprVec>("[1, 2, foo()]");
 /// ```
 #[derive(Debug, Clone, PartialEq, Eq, Parse, ToTokens, Spanned)]
+#[non_exhaustive]
 pub struct ExprVec {
     /// Attributes associated with vector.
     #[rune(iter, meta)]
