@@ -1,12 +1,11 @@
-use crate::ast;
-use crate::{Parse, Spanned, ToTokens};
+use crate::ast::prelude::*;
 
 /// A `yield [expr]` expression to return a value from a generator.
 ///
 /// # Examples
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
 /// testing::roundtrip::<ast::ExprYield>("yield");
 /// testing::roundtrip::<ast::ExprYield>("yield 42");
@@ -14,6 +13,7 @@ use crate::{Parse, Spanned, ToTokens};
 /// ```
 #[derive(Debug, Clone, PartialEq, Eq, Parse, ToTokens, Spanned)]
 #[rune(parse = "meta_only")]
+#[non_exhaustive]
 pub struct ExprYield {
     /// The attributes of the `yield`
     #[rune(iter, meta)]
@@ -22,7 +22,7 @@ pub struct ExprYield {
     pub yield_token: T![yield],
     /// An optional expression to yield.
     #[rune(iter)]
-    pub expr: Option<ast::Expr>,
+    pub expr: Option<Box<ast::Expr>>,
 }
 
 expr_parse!(Yield, ExprYield, "yield expression");
