@@ -1,22 +1,21 @@
-use crate::ast;
-use crate::{Id, Parse, Spanned, ToTokens};
-use runestick::Span;
+use crate::ast::prelude::*;
 
 /// A const declaration.
 ///
 /// # Examples
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
 /// testing::roundtrip::<ast::ItemConst>("const value = #{}");
 /// ```
-#[derive(Debug, Clone, PartialEq, Eq, Parse, ToTokens, Spanned)]
+#[derive(Debug, Clone, PartialEq, Eq, Parse, ToTokens, Spanned, Opaque)]
 #[rune(parse = "meta_only")]
+#[non_exhaustive]
 pub struct ItemConst {
     /// Opaque identifier for the constant.
     #[rune(id)]
-    pub id: Option<Id>,
+    pub(crate) id: Id,
     /// The *inner* attributes that are applied to the const declaration.
     #[rune(iter, meta)]
     pub attributes: Vec<ast::Attribute>,
@@ -37,7 +36,7 @@ pub struct ItemConst {
 impl ItemConst {
     /// Get the descriptive span of this item, e.g. `const ITEM` instead of the
     /// span for the whole expression.
-    pub fn descriptive_span(&self) -> Span {
+    pub(crate) fn descriptive_span(&self) -> Span {
         self.const_token.span().join(self.name.span())
     }
 }
