@@ -1,18 +1,18 @@
-use crate::ast;
-use crate::{Parse, ParseError, Parser, Spanned, ToTokens};
+use crate::ast::prelude::*;
 
 /// A local variable declaration `let <pattern> = <expr>;`
 ///
 /// # Examples
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
 /// testing::roundtrip::<ast::Local>("let x = 1;");
 /// testing::roundtrip::<ast::Local>("#[attr] let a = f();");
 /// testing::roundtrip::<ast::Local>("let a = b{}().foo[0].await;");
 /// ```
 #[derive(Debug, Clone, PartialEq, Eq, ToTokens, Parse, Spanned)]
+#[non_exhaustive]
 pub struct Local {
     /// The attributes for the let expression
     #[rune(iter, meta)]
@@ -31,10 +31,10 @@ pub struct Local {
 }
 
 fn parse_expr(p: &mut Parser<'_>) -> Result<ast::Expr, ParseError> {
-    Ok(ast::Expr::parse_with(
+    ast::Expr::parse_with(
         p,
-        ast::expr::EagerBrace(true),
-        ast::expr::EagerBinary(true),
-        ast::expr::Callable(true),
-    )?)
+        ast::expr::EAGER_BRACE,
+        ast::expr::EAGER_BINARY,
+        ast::expr::CALLABLE,
+    )
 }
