@@ -1,12 +1,10 @@
 use crate::ast;
+use crate::ast::{Span, Spanned, SpannedError, WithSpan};
 use crate::collections::HashMap;
-use crate::ir::IrValue;
-use crate::macros;
-use crate::macros::{MacroContext, Quote};
-use crate::quote;
-use crate::{Parse, ParseError, Parser, Peek, Spanned};
-use runestick::format;
-use runestick::{Span, SpannedError, WithSpan as _};
+use crate::compile::IrValue;
+use crate::macros::{quote, MacroContext, Quote};
+use crate::parse::{Parse, ParseError, Parser, Peek, Peeker};
+use crate::runtime::format;
 use std::collections::{BTreeMap, BTreeSet};
 
 // NB: needed for quote macro.
@@ -26,16 +24,7 @@ pub struct FormatArgs {
 
 impl FormatArgs {
     /// Expand the format specification.
-    ///
-    /// # Panics
-    ///
-    /// Panics if called outside of a macro context.
-    pub fn expand(&self) -> Result<Quote<'_>, SpannedError> {
-        macros::current_context(|ctx| self.expand_with(ctx))
-    }
-
-    /// Expand the format specification.
-    pub fn expand_with(&self, ctx: &MacroContext) -> Result<Quote<'_>, SpannedError> {
+    pub fn expand(&self, ctx: &mut MacroContext<'_>) -> Result<Quote<'_>, SpannedError> {
         let format = ctx.eval(&self.format)?;
 
         let mut pos = Vec::new();
@@ -54,7 +43,7 @@ impl FormatArgs {
                     pos.push(expr);
                 }
                 FormatArg::Named(n) => {
-                    let name = ctx.resolve_owned(n.key)?;
+                    let name = ctx.resolve(n.key)?;
                     named.insert(name.into(), n);
                 }
             }
@@ -130,7 +119,7 @@ impl Parse for FormatArgs {
 }
 
 impl Peek for FormatArgs {
-    fn peek(p: &mut crate::Peeker<'_>) -> bool {
+    fn peek(p: &mut Peeker<'_>) -> bool {
         !p.is_eof()
     }
 }
@@ -166,7 +155,7 @@ impl Parse for FormatArg {
 }
 
 fn expand_format_spec<'a>(
-    ctx: &MacroContext,
+    ctx: &mut MacroContext<'_>,
     span: Span,
     input: &str,
     pos: &[&'a ast::Expr],
@@ -240,7 +229,7 @@ fn expand_format_spec<'a>(
     for c in components {
         match c {
             C::Literal(literal) => {
-                let lit = ast::Lit::new(&*literal);
+                let lit = ctx.lit(&*literal);
                 args.push(quote!(#lit));
             }
             C::Format {
@@ -255,32 +244,32 @@ fn expand_format_spec<'a>(
                 let mut specs = Vec::new();
 
                 specs.extend(fill.map(|fill| {
-                    let fill = ast::LitChar::new(fill);
+                    let fill = ctx.lit(fill);
                     quote!(fill = #fill)
                 }));
 
                 specs.extend(width.map(|width| {
-                    let width = ast::Lit::new(width);
+                    let width = ctx.lit(width);
                     quote!(width = #width)
                 }));
 
                 specs.extend(precision.map(|precision| {
-                    let precision = ast::Lit::new(precision);
+                    let precision = ctx.lit(precision);
                     quote!(precision = #precision)
                 }));
 
                 specs.extend(align.map(|align| {
-                    let align = ast::Ident::new(&align.to_string());
+                    let align = ctx.ident(&align.to_string());
                     quote!(align = #align)
                 }));
 
                 if !flags.is_empty() {
-                    let flags = ast::Lit::new(flags.into_u32());
+                    let flags = ctx.lit(flags.into_u32());
                     specs.push(quote!(flags = #flags));
                 }
 
                 specs.extend(format_type.map(|format_type| {
-                    let format_type = ast::Ident::new(&format_type.to_string());
+                    let format_type = ctx.ident(&format_type.to_string());
                     quote!(type = #format_type)
                 }));
 
@@ -337,7 +326,7 @@ fn expand_format_spec<'a>(
 
     /// Parse a single expansion group.
     fn parse_group<'a>(
-        ctx: &MacroContext,
+        ctx: &mut MacroContext<'_>,
         span: Span,
         iter: &mut Iter<'_>,
         count: &mut usize,
@@ -529,7 +518,7 @@ fn expand_format_spec<'a>(
                 }
             };
 
-            unused_pos.remove(&count);
+            unused_pos.remove(count);
 
             let value = ctx.eval(*expr)?;
 
@@ -555,16 +544,14 @@ fn expand_format_spec<'a>(
 
             *count += 1;
             Some(precision)
+        } else if !precision.is_empty() {
+            str::parse::<usize>(precision).ok()
         } else {
-            if !precision.is_empty() {
-                str::parse::<usize>(&precision).ok()
-            } else {
-                None
-            }
+            None
         };
 
         let expr = if !name.is_empty() {
-            if let Ok(n) = str::parse::<usize>(&name) {
+            if let Ok(n) = str::parse::<usize>(name) {
                 let expr = match pos.get(n) {
                     Some(expr) => *expr,
                     None => {
@@ -602,13 +589,13 @@ fn expand_format_spec<'a>(
                 }
             };
 
-            unused_pos.remove(&count);
+            unused_pos.remove(count);
             *count += 1;
             expr
         };
 
         let width = if !width.is_empty() {
-            str::parse::<usize>(&width).ok()
+            str::parse::<usize>(width).ok()
         } else {
             None
         };
